==> dbsearch-1.0.0.tgz: package/index.js <==
var mysql = require('mysql');

module.exports = {
    generate_query: function(q, table) {

        q = analyse_q(q);
        table = analyse_table(table);
        var query = [];

        for (var i = 0; i < table.length; i += 1) {
            if ((table[i].colonne_text.length || colonne_numeric.length) && (q["numeric"].length || q["text"].length)) {
                var query_table = `SELECT \n` + table[i]['colonne_a_retourner_sql'].join(",\n") + `\nFROM ` + table[i]['table'];
                query_table += "\n" + table[i]['join'].join("\n ");
                query_table += `WHERE `;
                query_table += choose_where_strategy(q, table[i]);
                query_table += `\nLIMIT 30`;
            } else {
                return [];
            }

            query.push(query_table);
        }
        query = query.join(`\nUNION ALL\n`);

        console.log(q);
        console.log(table);
        return query;

    },
    execute_query: function(q, table, sql, callback) {
        var query = module.exports.generate_query(q, table);
        var connection = mysql.createConnection({
            host: sql.host,
            user: sql.user,
            password: sql.password
        });


        connection.query(query, function(err, rows) {
            callback(err, rows);
            connection.end();
        });
    }
};





function analyse_q(q) {
    var q = {
        all: q.replace(/ +(?= )/g, '').trim().split(' '),
        numeric: [],
        text: [],
    };

    for (var i = 0; i < q.all.length; i += 1) {
        if (!isNaN((q.all[i].charAt(0)))) {
            q["numeric"].push(q.all[i].replace(/\D/g, ""));
        } else {
            q["text"].push(q.all[i]);
        }
    }
    if (q['text'].length && !q['numeric'].length ){q['type'] = "text_only"}
    if (!q['text'].length && q['numeric'].length ){q['type'] = "numeric_only"}
    if (q['text'].length && q['numeric'].length ){q['type'] = "text_and_numeric"}
    return q;
}

function analyse_table(table) {
    table.max_colonne = 0;
    for (var i = 0; i < table.length; i += 1) {
        if (table[i]['colonne_a_retourner'].length > table.max_colonne) {
            table.max_colonne = table[i]['colonne_a_retourner'].length;
        }
        table[i]['colonne'] = table[i]['colonne_text'].concat(table[i]['colonne_numeric']);
        table[i]['colonne_a_retourner_sql'] = [];
        table[i]['colonne_a_retourner_sql'].push("'" + table[i]['type'] + "'" + ` AS 'type'`);
        for (var j = 0; j <= table.max_colonne; j += 1) {
            if (j < table[i]['colonne_a_retourner'].length) {
                table[i]['colonne_a_retourner_sql'].push(table[i]['colonne_a_retourner'][j] + ` AS 'col` + j + `'`)
            } else {
                table[i]['colonne_a_retourner_sql'].push(`'null' AS 'col` + j + `'`)
            }
        }
        if (table[i]['colonne_text'].length && !table[i]['colonne_numeric'].length){table[i]['colonne_type'] = "text_only"}
        if (!table[i]['colonne_text'].length && table[i]['colonne_numeric'].length){table[i]['colonne_type'] = "numeric_only"}
        if (table[i]['colonne_text'].length && table[i]['colonne_numeric'].length){table[i]['colonne_type'] = "text_and_numeric"}
    }
    return table;
}

function match(q, colonne) {
    return `\nMATCH (` + colonne.join() + `) AGAINST ('+` + q.join('* +') + `*' IN BOOLEAN MODE)`
}

function like(q, colonne) {
    var sql = [];
    for (var i = 0; i < colonne.length; i += 1) {
        sql.push(colonne[i] + ` LIKE  '` + q + `%'`);
    }
    return sql.join("\nOR ");
}

function like_or_match(q, colonne_numeric, colonne_text) {
    var sql = [];
    sql.push(like(q, colonne_numeric) + " OR " + match(q, colonne_text));
    return sql.join(" OR ");
}

function choose_where_strategy(q, table) {
    sql = [];

    //Si seulement colonne_text
    if (table['colonne_type'] == "text_only") {
        for (var i = 0; i < q.all.length; i += 1) {
            sql.push(match(q["all"], table.colonne_text));
        }
    }

    //Si seulement colonne_numeric
    if (table['colonne_type'] == "numeric_only") {
        if (q['type'] == "text_only") {
            sql.push(" 1 = 0 ");
        } else {
            for (var i = 0; i < q.all.length; i += 1) {
                sql.push(like(q.all, table.colonne_numeric));
            }
        }
    }

    //Si colonne_text && colonne_numeric
    if (table['colonne_type'] == "text_and_numeric") {
        if (q.type == "text_only") {
            // for (var i = 0; i < q.all.length; i += 1) {
                sql.push(match(q.all, table.colonne_text));
            // }
        } else if (q.type == "numeric_only") {
            for (var i = 0; i < q.all.length; i += 1) {
                sql.push(like_or_match(q.all, table.colonne_numeric, table.colonne_text));
            }
        } else if (q.type == "text_and_numeric") {
            for (var i = 0; i < q.text.length; i += 1) {
                sql.push(match(q.text, table.colonne_text));
            }
            for (var i = 0; i < q.numeric.length; i += 1) {
                sql.push(like_or_match(q.numeric, table.colonne_numeric, table.colonne_text));
            }
        }
    }
    // console.log("!!!!!!!!!!!!!!!!");
    // console.log(sql);
    return sql.join("\nAND ");
}

==> dbsearch-1.1.0.tgz: package/index.js <==
var mysql = require('mysql');

module.exports = {
    generate_query: function(q, table) {

        q = analyse_q(q);
        table = analyse_table(table);
        var query = [];

        for (var i = 0; i < table.length; i += 1) {
            if ((table[i].colonne_text.length || table[i].colonne_numeric.length) && (q["numeric"].length || q["text"].length)) {
                var query_table = `(SELECT \n` + table[i]['colonne_a_retourner_sql'].join(",\n") + `\nFROM ` + table[i]['table'];
                query_table += "\n" + table[i]['join'].join("\n ");
                query_table += `WHERE `;
                query_table += choose_where_strategy(q, table[i]);
                query_table += `\nLIMIT 30) `;
            } else {
                return [];
            }

            query.push(query_table);
        }
        query = query.join(`\nUNION ALL\n`);

        console.log(q);
        console.log(table);
        return query;

    },
    execute_query: function(q, table, sql, callback) {
        var query = module.exports.generate_query(q, table);
        var connection = mysql.createConnection({
            host: sql.host,
            user: sql.user,
            password: sql.password
        });


        connection.query(query, function(err, rows) {
            callback(err, rows);
            connection.end();
        });
    }
};





function analyse_q(q) {
    var q = {
        all: q.replace(/ +(?= )/g, '').trim().split(' '),
        numeric: [],
        text: [],
    };

    for (var i = 0; i < q.all.length; i += 1) {
        if (!isNaN((q.all[i].charAt(0)))) {
            q["numeric"].push(q.all[i].replace(/\D/g, ""));
        } else {
            q["text"].push(q.all[i]);
        }
    }
    if (q['text'].length && !q['numeric'].length ){q['type'] = "text_only"}
    if (!q['text'].length && q['numeric'].length ){q['type'] = "numeric_only"}
    if (q['text'].length && q['numeric'].length ){q['type'] = "text_and_numeric"}
    return q;
}

function analyse_table(table) {
    table.max_colonne = 0;
    for (var i = 0; i < table.length; i += 1) {
        if (table[i]['colonne_a_retourner'].length > table.max_colonne) {
            table.max_colonne = table[i]['colonne_a_retourner'].length;
        }
        table[i]['colonne'] = table[i]['colonne_text'].concat(table[i]['colonne_numeric']);
        table[i]['colonne_a_retourner_sql'] = [];
        table[i]['colonne_a_retourner_sql'].push("'" + table[i]['type'] + "'" + ` AS 'type'`);
        for (var j = 0; j <= table.max_colonne; j += 1) {
            if (j < table[i]['colonne_a_retourner'].length) {
                table[i]['colonne_a_retourner_sql'].push(table[i]['colonne_a_retourner'][j] + ` AS 'col` + j + `'`)
            } else {
                table[i]['colonne_a_retourner_sql'].push(`'null' AS 'col` + j + `'`)
            }
        }
        if (table[i]['colonne_text'].length && !table[i]['colonne_numeric'].length){table[i]['colonne_type'] = "text_only"}
        if (!table[i]['colonne_text'].length && table[i]['colonne_numeric'].length){table[i]['colonne_type'] = "numeric_only"}
        if (table[i]['colonne_text'].length && table[i]['colonne_numeric'].length){table[i]['colonne_type'] = "text_and_numeric"}
    }
    return table;
}

function match(q, colonne) {
    return `\nMATCH (` + colonne.join() + `) AGAINST ('+` + q.join('* +') + `*' IN BOOLEAN MODE)`
}

function like(q, colonne) {
    var sql = [];
    for (var i = 0; i < colonne.length; i += 1) {
        sql.push(colonne[i] + ` LIKE  '` + q + `%'`);
    }
    return sql.join("\nOR ");
}

function like_or_match(q, colonne_numeric, colonne_text) {
    var sql = [];
    sql.push(like(q, colonne_numeric) + " OR " + match(q, colonne_text));
    return sql.join(" OR ");
}

function choose_where_strategy(q, table) {
    sql = [];

    //Si seulement colonne_text
    if (table['colonne_type'] == "text_only") {
        for (var i = 0; i < q.all.length; i += 1) {
            sql.push(match(q["all"], table.colonne_text));
        }
    }

    //Si seulement colonne_numeric
    if (table['colonne_type'] == "numeric_only") {
        if (q['type'] == "text_only") {
            sql.push(" 1 = 0 ");
        } else {
            for (var i = 0; i < q.all.length; i += 1) {
                sql.push(like(q.all, table.colonne_numeric));
            }
        }
    }

    //Si colonne_text && colonne_numeric
    if (table['colonne_type'] == "text_and_numeric") {
        if (q.type == "text_only") {
            // for (var i = 0; i < q.all.length; i += 1) {
                sql.push(match(q.all, table.colonne_text));
            // }
        } else if (q.type == "numeric_only") {
            for (var i = 0; i < q.all.length; i += 1) {
                sql.push(like_or_match(q.all, table.colonne_numeric, table.colonne_text));
            }
        } else if (q.type == "text_and_numeric") {
            for (var i = 0; i < q.text.length; i += 1) {
                sql.push(match(q.text, table.colonne_text));
            }
            for (var i = 0; i < q.numeric.length; i += 1) {
                sql.push(like_or_match(q.numeric, table.colonne_numeric, table.colonne_text));
            }
        }
    }
    // console.log("!!!!!!!!!!!!!!!!");
    // console.log(sql);
    return sql.join("\nAND ");
}
